cgdat.qt_ui package — CGDAT 2.0.3-3-g9aff488 documentation

# cgdat.qt_ui package

## Submodules

## cgdat.qt_ui.about_ui module

class `cgdat.qt_ui.about_ui.` `Ui_About`

  Bases: `object`

  `retranslateUi`(About)
  `setupUi`(About)

## cgdat.qt_ui.cgdat_ui module

class `cgdat.qt_ui.cgdat_ui.` `Ui_MainWindow`

  Bases: `object`

  `retranslateUi`(MainWindow)
  `setupUi`(MainWindow)

## cgdat.qt_ui.import_dialog_ui module

class `cgdat.qt_ui.import_dialog_ui.` `Ui_ImportDialog`

  Bases: `object`

  `retranslateUi`(ImportDialog)
  `setupUi`(ImportDialog)

## cgdat.qt_ui.output_settings_ui module

class `cgdat.qt_ui.output_settings_ui.` `Ui_OutputSettings`

  Bases: `object`

  `retranslateUi`(OutputSettings)
  `setupUi`(OutputSettings)

## cgdat.qt_ui.progress_dialog_ui module

class `cgdat.qt_ui.progress_dialog_ui.` `Ui_ProgressDialog`

  Bases: `object`

  `retranslateUi`(ProgressDialog)
  `setupUi`(ProgressDialog)

## Module contents

This package contains all the QT python classes that were autogenearted out of the .ui files by the PyQt5.uic.pyuic module. It contains the following components:

> - About_ui.
> - cgdat_ui.
> - output_settings_ui.
> - progress_dialog_ui.
> - import_dialog_ui.

Note

Because these files were autogenerated no sphinx documentation is available for them. Go to the pyqt documentation for more information.